Method: AddEditEventMethods#custom_field_text
- Defined in:
- lib/kuali-sakai-common-lib/calendar.rb
#custom_field_text(field, text) ⇒ Object
Use this method to enter text into custom fields on the page. The “field” variable is the name of the field, while the “text” is the string you want to put into it.
297 298 299 |
# File 'lib/kuali-sakai-common-lib/calendar.rb', line 297 def custom_field_text(field, text) frm.text_field(:name=>field).set(text) end |